{ config, pkgs, ... }:

{
  imports =
    [
      ./hardware-configuration.nix
      ../../modules/cpu/intel.nix
      ../../modules/gpu/amd.nix
      ../../modules/libvirt.nix
      ../../modules/ssd.nix
      ../../modules
      ../../profiles/dev.nix
      ../../users/simon
    ];

  sbruder = {
    gui = true;
    restic.enable = true;
  };

  boot.loader.grub.device = "/dev/disk/by-id/ata-MTFDDAK256TBN-1AR15ABHA_UFZMQ01ZR50NMM";

  boot.initrd.luks.devices = {
    root = {
      name = "root";
      device = "/dev/disk/by-uuid/d7e4d213-8a13-4059-a011-0f68081e86d8";
      preLVM = true;
      allowDiscards = true;
    };
  };

  fileSystems.data = {
    mountPoint = "/data";
    device = "/dev/mapper/data";
    encrypted = {
      label = "data";
      enable = true;
      blkDev = "/dev/disk/by-uuid/576088d4-9aae-4159-a028-feadb2621a1a";
      keyFile = "/mnt-root" + toString ./secrets/data_luks_key;
    };
  };

  networking.hostName = "sayuri";

  networking.wireguard.interfaces.wg-home.ips = [ "10.80.0.5/24" ];
}
