# pass wrappers

function drone-add-hub() {
    drone secret add --name docker_username --data sbruder "$1"
    drone secret add --name docker_password --data "$(pass devops/docker|head -n 1)" "$1"
}

function drone-add-registry() {
    drone secret add --name docker_username --data simon "$1"
    drone secret add --name docker_password --data "$(pass sbruder.de/account|head -n 1)" "$1"
}

function drone-add-netlify() {
    drone secret add --name netlify_auth_token --data "$(pass-field web/netlify.com Drone-Key)" "$1"
}

function drone-add-s3() {
    drone secret add --name aws_access_key_id --data "$(pass-field sbruder.de/minio/personal User)" "$1"
    drone secret add --name aws_secret_access_key --data "$(pass sbruder.de/minio/personal|head -n 1)" "$1"
}

function drone() (
    export DRONE_SERVER="$(pass-field sbruder.de/drone Server)"
    export DRONE_TOKEN="$(pass sbruder.de/drone|head -n 1)"
    command drone $@
)

function docker-ls() (
    export DOCKER_LS_PASSWORD="$(pass sbruder.de/account|head -n 1)"
    command docker-ls $@
)

function docker-rm() (
    export DOCKER_LS_PASSWORD="$(pass sbruder.de/account|head -n 1)"
    command docker-rm $@
)

# Helpers

## resync pulseaudio bluetooth connection
function btsync() (
    card=$(pactl list cards short|grep -E -o "bluez_card.*[[:space:]]")
    pacmd set-card-profile $card off
    pacmd set-card-profile $card a2dp_sink
)

## get field from pass entry
function pass-field() {
    pass "$1"|grep "$2"|cut -d: -f2-|tr -d ' '
}

## Helper to create nix-shell direnv
function nixify() {
    if [ ! -e ./.envrc ]; then
        echo "use nix" > .envrc
        direnv allow
    fi
    if [[ ! -e shell.nix ]] && [[ ! -e default.nix ]]; then
        cat > shell.nix << EOF
{ pkgs ? import <nixpkgs> {} }:

pkgs.mkShell {
  buildInputs = with pkgs; [
  ];
}
EOF
    vim shell.nix
    fi
}

## Timer
function timer() (
    if [ -z "$1" ] || [ -z "$2" ]; then
        echo "USAGE: $0 [u|f] TIME/DURATION" >&2
        return 1
    fi

    if [ "$1" != "u" ] && [ "$1" != "f" ]; then
        echo "Invalid mode “$1” supplied. Valid modes are: u|f" >&2
        return 2
    fi

    [ "$1" = "u" ] && mode="until"
    [ "$1" = "f" ] && mode="for"

    gosleep --${mode} "$2"

    if [ "$?" = 0 ]; then
        echo "Press CTRL-C to stop the alarm…" >&2
        echo -en "\a" # highlight window
        paplay ~/Documents/sound/ringtones/Bergentrückung.wav
    else
        echo "The sleep command failed. Please check the options." >&2
        return 3
    fi
)

function currency() (
    amount=${1:-1}
    fromcurrency=${2:-USD}
    tocurrency=${3:-EUR}
    rate=$(curl -s "https://api.exchangeratesapi.io/latest?base=$fromcurrency&symbols=$tocurrency"|jq ".rates.$tocurrency")
    printf "$amount $fromcurrency: %.02f $tocurrency\n" $(($amount * $rate))
)

function urlencode() {
    python3 -c "import urllib.parse; print(urllib.parse.quote(open(0, 'rb').read()))"
}

function renumber() (
    if (( $# < 2 )); then
        echo "USAGE: $0 DIGITS FILES"
        return 1
    fi
    digits=$1
    shift 1
    i=1
    for file in $@; do
        mv -n "$file" "$(dirname $file)/$(printf %0${digits}d $i).${file##*.}"
        i=$((i+1))
    done
)

function mkvextract-all-attachments() {
    mkvextract $1 attachments $(mkvmerge --identify $1|grep "Attachment ID"|sed "s/Attachment ID \([0-9]*\): .*/\1/")
}

function mkvpropedit-add-attachments() (
    file="$1"
    shift
    for attachment in $@; do
        mkvpropedit --attachment-mime-type font/sfnt --add-attachment "$attachment" "$file"
    done
)

function ssim() {
    ffmpeg -loglevel fatal -i "$1" -i "$2" -lavfi 'ssim=/dev/stdout' -f null -
}

function mullvad() (
    if (( $# < 1 )); then
        echo "USAGE: $0 LOCATION|off" >&2
    fi
    current_interfaces="$(ip -o a|grep -oE '[0-9]*:\ mullvad-(v6-)?[a-z][a-z][0-9]*'|uniq|cut -d: -f2|tr -d ' ')"
    for current_interface in $current_interfaces; do
        sudo wg-quick down "$current_interface"
    done
    if [ "$1" != "off" ]; then
        sudo wg-quick up mullvad-$1
    fi
)
