{ pkgs, ... }:
let
  dircolors-solarized = pkgs.fetchFromGitHub {
    owner = "seebi";
    repo = "dircolors-solarized";
    rev = "65d4d595ceca96166139862131a006fa3079e00a";
    sha256 = "1nl5rs24gi7zqg7nqsbf9fa94yggwzqf3n3imxgfywl8jny3cj1q";
  };
in
{
  programs = {
    fzf.enable = true;
    direnv = {
      enable = true;
      enableNixDirenvIntegration = true;
    };
    starship = {
      enable = true;
      settings = {
        add_newline = false;
      };
    };
    zsh = {
      enable = true;
      plugins = [
        {
          name = "zsh-nix-shell";
          file = "nix-shell.plugin.zsh";
          src = pkgs.fetchFromGitHub {
            owner = "chisui";
            repo = "zsh-nix-shell";
            rev = "v0.1.0";
            sha256 = "0snhch9hfy83d4amkyxx33izvkhbwmindy0zjjk28hih1a9l2jmx";
          };
        }
      ];
      shellAliases = {
        exa = "exa --git --binary";
        l = "exa -l";
        la = "exa -la";
        ll = "exa -l";
        ls = "exa";
        ipy = "ipython3";
        vim = "nvim";
        vimdiff = "nvim -d";
        userctl = "systemctl --user";
      };
      envExtra = ''
        export _JAVA_OPTIONS="-Dawt.useSystemAAFontSettings=on"
      '';
      initExtraBeforeCompInit = ''
        source ${pkgs.grml-zsh-config}/etc/zsh/zshrc
      '';
      initExtra = ''
        eval $(${pkgs.coreutils}/bin/dircolors -b ${dircolors-solarized}/dircolors.ansi-universal)

        source ${../files/zsh/functions.zsh}
        source ${../files/zsh/docker.zsh}
      '';
    };
  };
}
